pub struct Feature {
pub id: Option<u64>,
pub tags: Vec<u32>,
pub type: Option<i32>,
pub geometry: Vec<u32>,
}Expand description
Features are described in section 4.2 of the specification
Fields
id: Option<u64>Tags of this feature are encoded as repeated pairs of integers. A detailed description of tags is located in sections 4.2 and 4.4 of the specification
type: Option<i32>The type of geometry stored in this feature.
geometry: Vec<u32>Contains a stream of commands and parameters (vertices). A detailed description on geometry encoding is located in section 4.3 of the specification.
Implementations