pub struct Layer {
pub version: u32,
pub name: String,
pub features: Vec<Feature>,
pub keys: Vec<String>,
pub values: Vec<Value>,
pub extent: Option<u32>,
}Expand description
Layers are described in section 4.1 of the specification
Fields
version: u32Any compliant implementation must first read the version number encoded in this message and choose the correct implementation for this version number before proceeding to decode other parts of this message.
name: Stringfeatures: Vec<Feature>The actual features in this tile.
keys: Vec<String>Dictionary encoding for keys
values: Vec<Value>Dictionary encoding for values
extent: Option<u32>Although this is an “optional” field it is required by the specification. See https://github.com/mapbox/vector-tile-spec/issues/47
Implementations